@@ -31,7 +31,7 @@ use base qw[ Class::Accessor::Fast ];
 __PACKAGE__->mk_accessors( qw[ _host _password _port  _version ] );
 
 
-our $VERSION = '0.4.2';
+our $VERSION = '0.5.0';
 
 
 #
@@ -133,8 +133,8 @@ sub spawn {
             },
             $playlist   => { # playlist related commands
                 # -- Playlist: retrieving information
-# #                 as_items
-# #                 items_changed_since
+                'pl.as_items'            => '_onpub_as_items',
+                'pl.items_changed_since' => '_onpub_items_changed_since',
                 # -- Playlist: adding / removing songs
                 'pl.add'               => '_onpub_add',
                 'pl.delete'            => '_onpub_delete',
